# Python 3 boilerplate template

[![docs](https://readthedocs.org/projects/py3-bp/badge/?version=latest)](https://readthedocs.org/projects/py3-bp/?badge=latest)

As a [freelancer](https://www.upwork.com/fl/andreyshpak) I often require
to do small projects on python. As any developer I do not like to do same
boilerplate work each time, but I like to work in expected environment.
So I decided to make this small project and include everything I often
need in one place.

This project for small non-web projects.

## Current project features

* None

## Project development plan

* Different licences templates
* Pytest requirement option
* tox requirement option
* nox requirement option
* SQLAlchemy+mysql requirement option
* Alembic requirement option
* Travis CI option
* Gitlab CI option
* AppVeyor CI option
* Sphinx documentation option

Currently this project is in 'I have an idea' stage.

## Project python version

This project is developed and tested on python version 3.6 and python 3.7.
